@@ -4,14 +4,15 @@ require "factory_bot"
 require "factory_bot_rails/generator"
 require "factory_bot_rails/reloader"
 require "factory_bot_rails/factory_validator"
+require "factory_bot_rails/file_fixture_support"
 require "rails"
 
 module FactoryBotRails
   class Railtie < Rails::Railtie
     config.factory_bot = ActiveSupport::OrderedOptions.new
     config.factory_bot.definition_file_paths = FactoryBot.definition_file_paths
-    config.factory_bot.reject_primary_key_attributes = true
     config.factory_bot.validator = FactoryBotRails::FactoryValidator.new
+    config.factory_bot.file_fixture_support = true
 
     initializer "factory_bot.set_fixture_replacement" do
       Generator.new(config).run
@@ -21,13 +22,19 @@ module FactoryBotRails
       FactoryBot.definition_file_paths = definition_file_paths
     end
 
-    ActiveSupport.on_load :active_record do
-      config = Rails.configuration.factory_bot
+    config.after_initialize do
+      if config.factory_bot.file_fixture_support
+        FactoryBot::SyntaxRunner.include FactoryBotRails::FileFixtureSupport
 
-      if config.reject_primary_key_attributes
-        require "factory_bot_rails/factory_validator/active_record_validator"
+        ActiveSupport.on_load :active_support_test_case do
+          setup { FactoryBot::SyntaxRunner.file_fixture_support = self }
+        end
 
-        config.validator.add_validator FactoryValidator::ActiveRecordValidator.new
+        if defined?(RSpec) && RSpec.respond_to?(:configure)
+          RSpec.configure do |config|
+            config.before { FactoryBot::SyntaxRunner.file_fixture_support = self }
+          end
+        end
       end
     end
 
