@@ -4,9 +4,8 @@ require "factory_bot_rails/definition_file_paths"
 
 module FactoryBotRails
   class Reloader
-    def initialize(app, config)
+    def initialize(app)
       @app = app
-      @config = config
       @paths = DefinitionFilePaths.new(FactoryBot.definition_file_paths)
     end
 
@@ -18,7 +17,7 @@ module FactoryBotRails
 
     private
 
-    attr_reader :app, :config
+    attr_reader :app
 
     def build_reloader
       reloader_class.new(@paths.files, @paths.directories) do
@@ -31,12 +30,8 @@ module FactoryBotRails
     end
 
     def register_reloader(reloader)
-      closed_over_app = app
-
-      config.to_prepare do
-        if closed_over_app.initialized?
-          reloader.execute
-        end
+      app.reloader.to_prepare do
+        reloader.execute
       end
 
       app.reloaders << reloader
